using System;
using System.ComponentModel;

namespace SharpLayout
{
	[TypeConverter(typeof(ExpandableObjectConverter))]
	public sealed class Borders
	{
		private bool _bottom;
		private bool _left;
		private bool _right;
		private bool _top;

		public Borders()
		{
		}


		[DefaultValue(false)]
		[DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		[RefreshProperties(RefreshProperties.Repaint)]
		public bool All
		{
			get
			{
				if (Left != Right)
					return false;
				else if (Left != Top)
					return false;
				else if (Left != Bottom)
					return false;
				else
					return Left;
			}
			set
			{
				if (Left != value || Right != value || Top != value || Bottom != value)
				{
					_left = value;
					_right = value;
					_top = value;
					_bottom = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(false)]
		public bool Bottom
		{
			get
			{
				return _bottom;
			}
			set
			{
				if (Bottom != value)
				{
					_bottom = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(false)]
		public bool Left
		{
			get
			{
				return _left;
			}
			set
			{
				if (Left != value)
				{
					_left = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(false)]
		public bool Right
		{
			get
			{
				return _right;
			}
			set
			{
				if (Right != value)
				{
					_right = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(false)]
		public bool Top
		{
			get
			{
				return _top;
			}
			set
			{
				if (Top != value)
				{
					_top = value;
					OnChanged();
				}
			}
		}


		public event EventHandler Changed;

		private void OnChanged()
		{
			EventHandler changed = Changed;
			if (changed != null)
				changed(this, EventArgs.Empty);
		}

	}
}