// Copyright  2004 by Joe White (joe@excastle.com).
// Licensed under the Artistic License. See Artistic.txt.

using System;
using System.ComponentModel;

namespace SharpLayout
{
	[TypeConverter(typeof(ExpandableObjectConverter))]
	public class Padding
	{
		private int _bottom;
		private int _left;
		private int _right;
		private int _top;

		public Padding()
		{
		}

		public Padding(int left, int top, int right, int bottom)
		{
			_left = left;
			_top = top;
			_right = right;
			_bottom = bottom;
		}


		[DefaultValue(0)]
		[DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		[RefreshProperties(RefreshProperties.Repaint)]
		public int All
		{
			get
			{
				if (Left != Right)
					return 0;
				else if (Left != Top)
					return 0;
				else if (Left != Bottom)
					return 0;
				else
					return Left;
			}
			set
			{
				if (Left != value || Right != value || Top != value || Bottom != value)
				{
					_left = value;
					_right = value;
					_top = value;
					_bottom = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(0)]
		[RefreshProperties(RefreshProperties.Repaint)]
		public int Bottom
		{
			get
			{
				return _bottom;
			}
			set
			{
				if (Bottom != value)
				{
					_bottom = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(0)]
		[RefreshProperties(RefreshProperties.Repaint)]
		public int Left
		{
			get
			{
				return _left;
			}
			set
			{
				if (Left != value)
				{
					_left = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(0)]
		[RefreshProperties(RefreshProperties.Repaint)]
		public int Right
		{
			get
			{
				return _right;
			}
			set
			{
				if (Right != value)
				{
					_right = value;
					OnChanged();
				}
			}
		}

		[DefaultValue(0)]
		[RefreshProperties(RefreshProperties.Repaint)]
		public int Top
		{
			get
			{
				return _top;
			}
			set
			{
				if (Top != value)
				{
					_top = value;
					OnChanged();
				}
			}
		}


		public event EventHandler Changed;

		public Padding Clone()
		{
			return new Padding(Left, Top, Right, Bottom);
		}

		private void OnChanged()
		{
			EventHandler changed = Changed;
			if (changed != null)
				changed(this, EventArgs.Empty);
		}

	}
}